@@ -2,6 +2,7 @@ import pytest
 from bs4 import BeautifulSoup
 
 from django.forms import fields, widgets
+from django.utils.html import strip_spaces_between_tags
 
 from entangled.forms import EntangledModelForm, EntangledModelFormMixin
 from .models import Product
@@ -22,12 +23,14 @@ class ProductForm(EntangledModelForm):
 def test_unsorted_form():
     product_form = ProductForm()
     assert product_form.is_bound is False
-    expected = BeautifulSoup("""
+    expected = BeautifulSoup(strip_spaces_between_tags("""
         <li><label for="id_name">Name:</label> <input type="text" name="name" required id="id_name"></li>
         <li><label for="id_active">Active:</label> <input type="checkbox" name="active" required id="id_active"></li>
         <li><label for="id_description">Description:</label> <textarea name="description" cols="40" rows="10" id="id_description">
-</textarea></li>""", features='lxml')
-    assert BeautifulSoup(product_form.as_ul(), features='lxml') == expected
+</textarea></li>"""),
+        features='lxml',
+    )
+    assert BeautifulSoup(strip_spaces_between_tags(product_form.as_ul()), features='lxml') == expected
 
 
 class SortedProductForm(ProductForm):
@@ -43,12 +46,14 @@ def test_sorted_form():
     product_form = SortedProductForm()
     assert product_form.is_bound is False
     print(product_form.as_ul())
-    expected = BeautifulSoup("""
+    expected = BeautifulSoup(strip_spaces_between_tags("""
         <li><label for="id_active">Active:</label> <input type="checkbox" name="active" required id="id_active"></li>
         <li><label for="id_description">Description:</label> <textarea name="description" cols="40" rows="10" id="id_description">
 </textarea></li>
-        <li><label for="id_name">Name:</label> <input type="text" name="name" required id="id_name"></li>""", features='lxml')
-    assert BeautifulSoup(product_form.as_ul(), features='lxml') == expected
+        <li><label for="id_name">Name:</label> <input type="text" name="name" required id="id_name"></li>"""),
+        features='lxml',
+    )
+    assert BeautifulSoup(strip_spaces_between_tags(product_form.as_ul()), features='lxml') == expected
 
 
 class UnsortedBookForm(ProductForm):
@@ -63,13 +68,15 @@ class UnsortedBookForm(ProductForm):
 def test_simple_inheritance_unsorted():
     product_form = UnsortedBookForm()
     assert product_form.is_bound is False
-    expected = BeautifulSoup("""
+    expected = BeautifulSoup(strip_spaces_between_tags("""
         <li><label for="id_name">Name:</label> <input type="text" name="name" required id="id_name"></li>
         <li><label for="id_active">Active:</label> <input type="checkbox" name="active" required id="id_active"></li>
         <li><label for="id_description">Description:</label> <textarea name="description" cols="40" rows="10" id="id_description">
 </textarea></li>
-        <li><label for="id_author">Author:</label> <input type="text" name="author" required id="id_author"></li>""", features='lxml')
-    assert BeautifulSoup(product_form.as_ul(), features='lxml') == expected
+        <li><label for="id_author">Author:</label> <input type="text" name="author" required id="id_author"></li>"""),
+        features='lxml',
+    )
+    assert BeautifulSoup(strip_spaces_between_tags(product_form.as_ul()), features='lxml') == expected
 
 
 class SortedBookForm(ProductForm):
@@ -85,13 +92,15 @@ class SortedBookForm(ProductForm):
 def test_simple_inheritance_sorted():
     product_form = SortedBookForm()
     assert product_form.is_bound is False
-    expected = BeautifulSoup("""
+    expected = BeautifulSoup(strip_spaces_between_tags("""
         <li><label for="id_author">Author:</label> <input type="text" name="author" required id="id_author"></li>
         <li><label for="id_active">Active:</label> <input type="checkbox" name="active" required id="id_active"></li>
         <li><label for="id_name">Name:</label> <input type="text" name="name" required id="id_name"></li>
         <li><label for="id_description">Description:</label> <textarea name="description" cols="40" rows="10" id="id_description">
-</textarea></li>""", features='lxml')
-    assert BeautifulSoup(product_form.as_ul(), features='lxml') == expected
+</textarea></li>"""),
+        features='lxml',
+    )
+    assert BeautifulSoup(strip_spaces_between_tags(product_form.as_ul()), features='lxml') == expected
 
 
 class QuantityMixin(EntangledModelFormMixin):
@@ -113,14 +122,16 @@ class QuantifiedUnsortedProductForm(QuantityMixin, ProductForm):
 def test_multiple_inheritance_unsorted():
     product_form = QuantifiedUnsortedProductForm()
     assert product_form.is_bound is False
-    expected = BeautifulSoup("""
+    expected = BeautifulSoup(strip_spaces_between_tags("""
         <li><label for="id_name">Name:</label> <input type="text" name="name" required id="id_name"></li>
         <li><label for="id_active">Active:</label> <input type="checkbox" name="active" required id="id_active"></li>
         <li><label for="id_description">Description:</label> <textarea name="description" cols="40" rows="10" id="id_description">
 </textarea></li>
         <li><label for="id_quantity">Quantity:</label> <input type="number" name="quantity" required id="id_quantity"></li>
-        <li><label for="id_unit">Unit:</label> <input type="text" name="unit" required id="id_unit"></li>""", features='lxml')
-    assert BeautifulSoup(product_form.as_ul(), features='lxml') == expected
+        <li><label for="id_unit">Unit:</label> <input type="text" name="unit" required id="id_unit"></li>"""),
+        features='lxml',
+    )
+    assert BeautifulSoup(strip_spaces_between_tags(product_form.as_ul()), features='lxml') == expected
 
 
 class QuantifiedSortedProductForm(QuantityMixin, ProductForm):
@@ -136,11 +147,13 @@ class QuantifiedSortedProductForm(QuantityMixin, ProductForm):
 def test_multiple_inheritance_sorted():
     product_form = QuantifiedSortedProductForm()
     assert product_form.is_bound is False
-    expected = BeautifulSoup("""
+    expected = BeautifulSoup(strip_spaces_between_tags("""
         <li><label for="id_active">Active:</label> <input type="checkbox" name="active" required id="id_active"></li>
         <li><label for="id_unit">Unit:</label> <input type="text" name="unit" required id="id_unit"></li>
         <li><label for="id_name">Name:</label> <input type="text" name="name" required id="id_name"></li>
         <li><label for="id_quantity">Quantity:</label> <input type="number" name="quantity" required id="id_quantity"></li>
         <li><label for="id_description">Description:</label> <textarea name="description" cols="40" rows="10" id="id_description">
-</textarea></li>""", features='lxml')
-    assert BeautifulSoup(product_form.as_ul(), features='lxml') == expected
+</textarea></li>"""),
+        features='lxml',
+    )
+    assert BeautifulSoup(strip_spaces_between_tags(product_form.as_ul()), features='lxml') == expected
